********************************************************
*
* MSS_12_188_Using_Cash_to_Monitor_Liquidity_STATA_DATA PREPARATION.do
*
* This file generates the variable needed for the analysis doen in 
* von Kalckreuth et al. "Using Cash to Monitor Liquidity  Implications for Payments, Currency Demand and Withdrawal Behavior"
*
* Database: capi_papi_final.dta
*
* This version: Novmeber 18, 2013 
*
********************************************************


* Settings
* ========

clear all
clear matrix
set more off
set mem 450m
set maxvar 10000
cap log close
window manage maintitle "von Kalckreuth et al. - Using Cash to Monitor Liquidity"

global path "R:\Zentrale\6\Daten\6_Datenaustausch\Haushaltssurvey\Germany - Bargeldumfrage H\Analysen, Projekte, Stix\Paper II\Submissions\JMCB\Files for Publication"
cd "$path"
	
	
* Read in Data
* ============

	  use  "R:\Zentrale\6\Daten\6_Datenaustausch\Haushaltssurvey\Germany - Bargeldumfrage H\Bargeldstudie 2008\Datenstze\Stata\capi_papi_final.dta", clear

* Generate Variables

	* id
	
	* age and age2
	
		gen age = s1
		replace age = . if age==99
		label var age "age"

		gen age2 = age*age
		label var age2 "Age (squared)"
	  
	* gender/male
	
		gen male = .
		replace male = 1 if s3==2
		replace male = 0 if s3==1

		label define male 1 "male" 0 "female"
		label val male male
		label var male "gender"

	* education
	
		gen education = s5
		replace education = . if education==8

		label val education s5 
		label var education "education"

	* EDU_LOW, EDU_MEDIUM, EDU_HIGH, EDU_UNI
		
		gen EDU_LOW=0
		replace EDU_LOW=1 if education==1 | education==2
		replace EDU_LOW=. if education==.

		gen EDU_MEDIUM=0
		replace EDU_MEDIUM=1 if education==3 | education==4
		replace EDU_MEDIUM=. if education==.
		
		gen EDU_HIGH=0
		replace EDU_HIGH=1 if education==5
		replace EDU_HIGH=. if education==.
		
		gen EDU_UNI=0
		replace EDU_UNI=1 if education==6
		replace EDU_UNI=. if education==.
	
		label var EDU_LOW "(noch) kein Abschluss, Hauptschule / Volksschulabschluss"
		label var EDU_MEDIUM "mittlere Reife, Realschulabschluss, Handelsschule, Polytechn. Oberschule, 10. Klasse"
		label var EDU_HIGH   "Fachhochschulreife, Abschluss FOS, Abitur"
		label var EDU_UNI   "Fachhochschulabschluss, Universittsabschluss"
	
	* edu_m_high_uni
	
		gen edu_m_high_uni=0
		replace edu_m_high_uni=1 if EDU_HIGH==1 | EDU_UNI==1 | EDU_MEDIUM==1
		replace edu_m_high_uni=. if EDU_HIGH==. & EDU_UNI==. & EDU_MEDIUM==.
		
			
	* pinc_mitte
	
		gen p_income = s11b
		replace p_income = . if p_income==13

		label val p_income s11b 
		label var p_income "personal net income"

		gen pinc_mitte=.
		replace pinc_mitte=(500/2)              if p_income==1
		replace pinc_mitte=500 +((1000- 500)/2) if p_income==2
		replace pinc_mitte=1000+((1500-1000)/2) if p_income==3
		replace pinc_mitte=1500+((2000-1500)/2) if p_income==4
		replace pinc_mitte=2000+((2500-2000)/2) if p_income==5
		replace pinc_mitte=2500+((3000-2500)/2) if p_income==6
		replace pinc_mitte=3000+((3500-3000)/2) if p_income==7
		replace pinc_mitte=3500+((4000-3500)/2) if p_income==8
		replace pinc_mitte=4000+((4500-4000)/2) if p_income==9
		replace pinc_mitte=4500+((5000-4500)/2) if p_income==10
		replace pinc_mitte=5000+((7000-5000)/2) if p_income==11
		replace pinc_mitte=8000                 if p_income==12
	
		label var pinc_mitte "personal net income (mid points)"
	
	* HH_INC
	
		gen hh_income = s11a
		replace hh_income = . if hh_income==13 

		label val hh_income s11a
		label var hh_income "HH net income"
	
	  * Generate hh income based on mid-point of interval scaled variable
	
		gen hh_income_mitte=.
		replace hh_income_mitte=(500/2) 			 if hh_income==1
		replace hh_income_mitte=500 +((1000- 500)/2) if hh_income==2
		replace hh_income_mitte=1000+((1500-1000)/2) if hh_income==3
		replace hh_income_mitte=1500+((2000-1500)/2) if hh_income==4
		replace hh_income_mitte=2000+((2500-2000)/2) if hh_income==5
		replace hh_income_mitte=2500+((3000-2500)/2) if hh_income==6
		replace hh_income_mitte=3000+((3500-3000)/2) if hh_income==7
		replace hh_income_mitte=3500+((4000-3500)/2) if hh_income==8
		replace hh_income_mitte=4000+((4500-4000)/2) if hh_income==9
		replace hh_income_mitte=4500+((5000-4500)/2) if hh_income==10
		replace hh_income_mitte=5000+((7000-5000)/2) if hh_income==11
		replace hh_income_mitte=8000 if hh_income==12

		label var hh_income_mitte "HH net income (mid points)"


    *	natural log of HH net income (mid points)

		gen HH_INC=ln(hh_income_mitte)

		label var HH_INC "ln of HH net income (mid points)"
		
	* employed
	
		gen employed = 0
		replace employed = 1 if (s6_01==1 | s6_02==1)
		replace employed = . if s6_14==1

		label define employed 1 "currently employed" 0 "currently not employed"
		label val employed employed
		label var employed "currently employed (dummy)"

	* unemployed

		gen unemployed=0
		replace unemployed=1 if s6_05==1
		replace unemployed=. if s6_14==1

		label define unempl 1 "currently looking for work" 0 "currently not looking for work"
		label val unemployed unempl
		label var unemployed "currently looking for work(dummy)"	

	* retired

		gen retired=0
		replace retired = 1 if s6_08==1 | s6_09==1
		replace retired = . if s6_14==1

		label define retired 1 "currently retired or permanently disabled" 0 "currently not retired or permanently disabled"
		label val retired retired
		label var retired "currently retired or dauerhaft berufsunfhig (dummy)"

  * other employment status

		gen other=0
		replace other=1 if (s6_03==1 | s6_04==1 | s6_06==1 | s6_07==1 | s6_10==1 | s6_11==1 | s6_12==1 | s6_13==1) & employed!=1 & retired!=1 & unemployed!=1
		replace other=. if s6_14==1

		label var other "other employment status"

  * BIK size classes
		
		drop gkz plz
		merge 1:1 id using "R:\Zentrale\6\Daten\6_Datenaustausch\Haushaltssurvey\Germany - Bargeldumfrage H\Bargeldstudie 2008\Datenstze\Stata\id_bik.dta"
		drop _merge
		destring bik, replace
		drop gkz plz
		
		label define bik_07 1 "bis 1.999 Personen" 2 "2.000-4.999 Personen" 3 "5.000-19.999 Personen" 4 "20.000-49.999 Personen" 5 "50.000-99.999 Personen" 6 "100.000-499.999 Personen" 7 "500.000 und mehr Personen"
		label val bik_07 bik_07
		label var bik_07 "Municipality size class"

   * BIK Dummies  bik_1 - bik_7

		 tab bik, gen (bik_)
		 
   * risk_theft
   
		sum f9 if f9<999998
		gen risk_theft=.
		replace risk_theft=1-exp((-1/r(mean))*f9) if f9<999998
		replace risk_theft=1 if f9==999998
		replace risk_theft=1-risk_theft

		label var risk_theft "exponentially transformed amount of cash for which person is afraid of theft"
			
	* ec_card
	
		gen ec_card=.
		replace ec_card=1 if f12_1==1
		replace ec_card=0 if f12_1>=2 & f12_1<=4
		label var ec_card "person owns maestro debit card"
		
	* NUM_DIFF_PI
	
		for numlist 1/4: egen countX=rsum(f16_1_X f16_2_X f16_3_X f16_4_X f16_5_X f16_6_X) if f15_01!=1
		for numlist 1/4: replace countX=1 if (countX>0 & countX!=.)
		replace count1=1 if f15_01==1
		egen NUM_DIFF_PI=rsum(count1 count2 count3 count4) if f15_01!=.
		label var NUM_DIFF_PI "number of different payment instruments used"
		
	* ausgaben
	
		gen ausgaben=.
		replace ausgaben=1 if f28_1==1
		replace ausgaben=0 if f28_1>1 & f28_1!=.

		label define ausg 1 "very important to keep overview of expenditures" 0 "less important to keep overview"
		label val ausgaben ausg
		label var ausgaben "importance of keeping overview of expenditures"	
		
	* P_EXPCONTR_CASH
	
		gen P_EXPCONTR_CASH=0 if f13_6==1 | f13_6==2 | f13_6==3 
		replace P_EXPCONTR_CASH=1 if f13_6==1 & f14_6_1==1 & f14_6_2!=1 & f14_6_3!=1 & f14_6_4!=1 & f14_6_5!=1 & f14_6_6!=1
			
		label var P_EXPCONTR_CASH "Person indicates that expenditure control is an indispensable attribute of a pi and ONLY CASH fullfills it"

	* sec_pro_quest
	
		* total length of interview
	
			merge 1:1 id using "R:\Zentrale\6\Daten\6_Datenaustausch\Haushaltssurvey\Germany - Bargeldumfrage H\Bargeldstudie 2008\Datenstze\Interviewdauern\interviewdauer.dta"
			keep if _merge==3
			drop _merge
			
		
		* number of "questions" answered

			egen questions_nomiss=rownonmiss(f1 - s11b)
			egen questions_miss=rowmiss(f1 - s11b)
		
		gen sec_pro_quest=interviewdauer/questions_nomiss
		
	* IA2_EXPC_LENGTH
	
	  * determine whether average length is below or above median
	  
			sum sec_pro_quest if sec_pro_quest!=. & ec_card==1, d
			gen help=r(p50)		
			gen length_umedian=0 
			replace length_umedian=1 if sec_pro_quest<=help
			replace length_umedian=. if sec_pro_quest==. 
			drop help	
	
		gen IA2_EXPC_LENGTH=0 if ausgaben==1 & length_umedian==0
		replace IA2_EXPC_LENGTH=1 if ausgaben==0 & length_umedian==1
	
	* ausgaben_length2
	
		gen ausgaben_length2=1 if IA2_EXPC_LENGTH==0
		replace ausgaben_length2=0 if IA2_EXPC_LENGTH==1
		replace ausgaben_length2=2 if (ausgaben==1 & length_umedian==1) |(ausgaben==0 & length_umedian==0)
	
	* CASHP_ALL 
	
		gen CASHP_ALL=f15_01
		
		label var CASHP_ALL "Person always pays cash"
		
	* CASHP_MAINLOC
	
		gen CASHP_MAINLOC=0
		replace CASHP_MAINLOC=1 if f15_01==1 | (f17_1_01==1 & f17_2_01==1 & f17_3_01==1 & f17_5_01==1)
		replace CASHP_MAINLOC=. if f15_09==1 | (f17_1_19==1 | f17_2_19==1 | f17_3_19==1 | f17_5_19==1) | (f17_1_20==1 | f17_2_20==1 | f17_3_20==1 | f17_5_20==1) |  (f17_1_21==1 | f17_2_21==1 | f17_3_21==1 | f17_5_21==1)	
		
		label var CASHP_MAINLOC "Person (also) pays cash in retail shops, at gas stations and services consumed outside house"

	* CASHP_B100 
	
		gen CASHP_B100 =0
		replace CASHP_B100 =1 if f15_01==1 | (f16_1_1==1 & f16_2_1==1 & f16_3_1==1 & f16_4_1==1)
		replace CASHP_B100 =. if f15_09==1 | f16_1_6==1 | f16_2_6==1 | f16_3_6==1 | f16_4_6==1		
		
		label var CASHP_B100  "Person pays cash if amount payable is below 100 Euros"
	
	* SHARE_CASH_TRANS
	
	qui {
	
		* Number of cash transactions with the option to pay non-cash
			
				forvalue day=1/7 {
					for numlist 1/56: gen bar_`day'_X=1 if c3`day'X==1 & c4`day'X==1
							   }
			 
					egen bar_sum=rsum(bar_1_1- bar_7_56)
					replace bar_sum=. if bar_sum==0 & pag_nr==.
			
		* Number of transactions with a payment option  - assumption all non-cash payments have cash option

   
			forvalue day=1/7 {
				for numlist 1/56: gen gesamt_sum_`day'_X=1 if c4`day'X==1 | c3`day'X==2
		                       }
		 
			   	egen gesamt_sum=rsum(gesamt_sum_1_1 - gesamt_sum_7_56)
       			replace gesamt_sum=. if gesamt_sum==0 & pag_nr==.

    }

 	
		gen SHARE_CASH_TRANS=(bar_sum/gesamt_sum)
		rename gesamt_sum gesamt_opt_sum
		drop gesamt_sum* bar_*
		
		label var SHARE_CASH_TRANS "Share of cash transactions of total transactions with options"
		
	
	* SHARE_CASH_VALUE 
	
    qui  { 
	
	
	   * Value of cash transactions with the option to pay non-cash
	   
			forvalue day=1/7 {
						for numlist 1/56: gen bar_vol_`day'_X=zahlungsbetrag_`day'_X if c3`day'X==1 & c4`day'X==1 
								   }

							 egen bar_vol=rsum(bar_vol_1_1 - bar_vol_7_56)
							 replace bar_vol=. if bar_vol==0 & pag_nr==.

			
   * Value of all transactions with a payment option  - assumption all non-cash payments have cash option

			forvalue day=1/7  {
    					for numlist 1/56: gen gesamt_vol_`day'_X=zahlungsbetrag_`day'_X  if c4`day'X==1 | c3`day'X==2  
                         }

					egen gesamt_vol=rsum(gesamt_vol_1_1 - gesamt_vol_7_56)
    				replace gesamt_vol=. if gesamt_vol==0 & pag_nr==.

         }

		gen SHARE_CASH_VALUE=(bar_vol/gesamt_vol)
		rename gesamt_vol gesamt_opt_vol
		drop gesamt_vol* bar_vol*
		
		label var SHARE_CASH_VALUE "Share of value of cash transactions with options of total transaction value"
		

	* THRESH_CARD

		gen THRESH_CARD=.
		replace THRESH_CARD=500 if f15_01==1 
		for numlist 1/6: egen helpX=rsum(f16_X_2- f16_X_5) if f15_01!=1
		replace THRESH_CARD=0    if help1>=1 & help1!=. & THRESH_CARD==.
		replace THRESH_CARD=5    if help2>=1 & help2!=. & THRESH_CARD==.
		replace THRESH_CARD=20   if help3>=1 & help3!=. & THRESH_CARD==.
		replace THRESH_CARD=50   if help4>=1 & help4!=. & THRESH_CARD==.
		replace THRESH_CARD=100  if help5>=1 & help5!=. & THRESH_CARD==.
		replace THRESH_CARD=500  if help6>=1 & help6!=. & THRESH_CARD==.
		
		egen help=rsum(f16_1_2- f16_1_5 f16_2_2- f16_2_5 f16_3_2- f16_3_5 f16_4_2- f16_4_5 f16_5_2- f16_5_5) if f15_01!=1
		replace THRESH_CARD=500 if help==0 & THRESH_CARD==.
		
		label var THRESH_CARD "Threshold at which the person starts paying with cards"
		
	* DIST_WITHDR
	
		gen dist_withdraw = f7a
		replace dist_withdraw = . if f7a==997 | f7a==999
		gen DIST_WITHDR=ln(dist_withdraw)
		
		label var DIST_WITHDR "natural log of distance to next source of cash (in minutes)"

	* fees 
	
		gen fees=0
		replace fees=1 if f2==3
		replace fees=. if f2==4
		
		label var fees "line fees for current account (Yes/No)"
	
	* ATM_USER
	
		gen ATM_USER=.
		replace ATM_USER=1 if f4_1>=1 & f4_1<=3
		replace ATM_USER=0 if f4_1>=4 & f4_1<=9

		label var ATM_USER "person uses ATM at least once a week (YES/NO)"
	
	* AVGWITHDAM 
	
		gen AVGWITHDAM=f5_1 if f5_1<999999
	
	* lnAVGWITHDAM
	
		gen lnAVGWITHDAM=ln(AVGWITHDAM)
		
	* Threshold of cash in the pocket before next withdrawal (Scale: Amount in Pocket)
	
		gen bodensatz=f8 if f8<999999

		gen bargeldbestand_tb=.
		replace bargeldbestand_tb=0 if a1000==1
		replace bargeldbestand_tb=  n1010* 0.01+ n1020* 0.02+ n1030*0.05+ n1040*0.1+ n1050*0.2+ n1060*0.5+ n1070+ n1080*2+ n1090*5+ n1100*10+ n1110*20+ n1120*50+ n1130*100+ n1140*200+ n1150*500
		replace  bargeldbestand_tb= . if bargeldbestand_tb==0 |  bargeldbestand_tb>5000	
		gen thresh_nextwithdr=bodensatz/bargeldbestand_tb
		keep if thresh_nextwithdr<10
		label var thresh_nextwithdr "Threshold of cash in the pocket before next withdrawal (Scale: Amount in Pocket)"
		drop bargeldbestand_tb bodensatz
		
		
	* lnamount
	
		qui {
			gen     withdraw_frqy_ATM=3*52   if f4_1==1
			replace withdraw_frqy_ATM=2*52   if f4_1==2
			replace withdraw_frqy_ATM=52     if f4_1==3
			replace withdraw_frqy_ATM=24     if f4_1==4
			replace withdraw_frqy_ATM=12     if f4_1==5
			replace withdraw_frqy_ATM=4      if f4_1==6
			replace withdraw_frqy_ATM=2  	 if f4_1==7
			replace withdraw_frqy_ATM=1	     if f4_1==8
			replace withdraw_frqy_ATM=0	     if f4_1==9

			gen     withdraw_frqy_desk=3*52   if f4_2==1
			replace withdraw_frqy_desk=2*52   if f4_2==2
			replace withdraw_frqy_desk=52     if f4_2==3
			replace withdraw_frqy_desk=24     if f4_2==4
			replace withdraw_frqy_desk=12     if f4_2==5
			replace withdraw_frqy_desk=4      if f4_2==6
			replace withdraw_frqy_desk=2      if f4_2==7
			replace withdraw_frqy_desk=1      if f4_2==8
			replace withdraw_frqy_desk=0	  if f4_2==9

			gen ATM_amount=f5_1 if f5_1<999999
			gen desk_amount=f5_2 if f5_2<999999

			gen wamount_ATM_year=(withdraw_frqy_ATM*ATM_amount)
			gen wamount_desk_year=(withdraw_frqy_desk*desk_amount)
			egen wamount=rsum(wamount_ATM_year wamount_desk_year)
			
			gen amount=wamount/12
			gen lnamount=ln(amount)
		}
	
	* withdraw_frq_unscaled
	
		egen withdraw_frq_unscaled=rsum(withdraw_frqy_desk withdraw_frqy_ATM)
		replace withdraw_frq_unscaled=withdraw_frq_unscaled /12
		label var withdraw_frq_unscaled "Average monthly withdrawal frequency (unscaled)" 
		
	
	* anteil_barvol_gesamt
	
	qui  {
	
	  * Total value of cash transactions
	  
		forvalue day=1/7 {

					for numlist 1/56: gen bar_vol_`day'_X=zahlungsbetrag_`day'_X if c3`day'X==1 

							   }

					     egen bar_vol=rsum(bar_vol_1_1 - bar_vol_7_56)
						 replace bar_vol=. if bar_vol==0 & pag_nr==.

					
	   * Total value of all transactions


		forvalue day=1/7     {

							for numlist 1/56: gen gesamt_vol_`day'_X=zahlungsbetrag_`day'_X   
						   
							 }

						egen gesamt_vol=rsum(gesamt_vol_1_1 - gesamt_vol_7_56)
						replace gesamt_vol=. if gesamt_vol==0 & pag_nr==.

	}



		

		gen anteil_barvol_gesamt=(bar_vol/gesamt_vol)
		drop gesamt_vol* bar_vol*
			
		label var anteil_barvol_gesamt "Share of value of cash transactions of total transaction value"

	
	* AVG_VAL_TRANS
	
		gen AVG_VAL_TRANS=gesamt_opt_vol/gesamt_opt_sum
		replace AVG_VAL_TRANS=AVG_VAL_TRANS/100
		
	* sectoral_trans1 - sectoral_trans9
	
			* Program to count the number of transactions at a given location

				cap prog drop zahlungsort
				prog define zahlungsort

					local zahlungsort `1'
					local kriterium `2'
				  
				 cap drop sum_`zahlungsort'


				qui{


						forvalue day=1/7 {
		
							for numlist 1/56: gen `zahlungsort'_`day'_X=1 if c1`day'X_1==`kriterium'

									   }
					 

							egen `zahlungsort'_sum=rsum(`zahlungsort'_1_1- `zahlungsort'_7_56)
							replace `zahlungsort'_sum=. if `zahlungsort'_sum==0 & pag_nr==.
							
							drop `zahlungsort'_1_1- `zahlungsort'_7_56
				}



				end

		  * Start program for each location
		  
				zahlungsort frequent_retail 1
				zahlungsort infrequent_retail 2
				zahlungsort gasoline 3
				zahlungsort drugstore 4
				zahlungsort outhouse_services 5
				zahlungsort inhouse_services 6
				zahlungsort automat 8
				zahlungsort internet_orders 9
				zahlungsort mail_orders 10
				zahlungsort restaurant 11
				zahlungsort cafe_bar 12
				zahlungsort leisure 13
				zahlungsort hotel 14
				zahlungsort expend_privatpers 15
				zahlungsort pocketmoney 16
				zahlungsort cash_savings 17
				zahlungsort other 18
				zahlungsort noresponse 19


		 *	Aggregate Payment structure
		 
				gen sectoral_t_1 = frequent_retail_sum
				gen sectoral_t_2 = infrequent_retail_sum
				gen sectoral_t_3 = gasoline_sum
				egen sectoral_t_4 = rsum(restaurant_sum hotel_sum cafe_bar_sum)
				egen sectoral_t_5 = rsum(internet_orders_sum mail_orders_sum)
				gen sectoral_t_6 = outhouse_services_sum
				egen sectoral_t_7 = rsum(inhouse_services_sum expend_privatpers_sum pocketmoney_sum)
				egen sectoral_t_8 = rsum(leisure_sum drugstore_sum automat_sum)
				egen sectoral_t_9 = rsum(cash_savings_sum other_sum noresponse_sum)
	 
		* Calculate total number of transactions per person

			gen trans_perp=sectoral_t_1+sectoral_t_2+sectoral_t_3+sectoral_t_4+sectoral_t_5+sectoral_t_6+sectoral_t_7+sectoral_t_8+sectoral_t_9
			label var trans_perp "Number of transactions for one person"
		
		
		gen sectoral_trans_1 = sectoral_t_1/trans_perp
		label val sectoral_trans_1 sec_trans_1
		label var sectoral_trans_1 "Share (number of trans): frequent retail expenditures"

		gen sectoral_trans_2 = sectoral_t_2/trans_perp
		label val sectoral_trans_2 sec_trans_2
		label var sectoral_trans_2 "Share (number of trans):infrequent retail expenditures"

		gen sectoral_trans_3 = sectoral_t_3/trans_perp
		label val sectoral_trans_3 sec_trans_3
		label var sectoral_trans_3 "Share (number of trans):gasoline"

		gen sectoral_trans_4 = sectoral_t_4/trans_perp
		label val sectoral_trans_4 sec_trans_4
		label var sectoral_trans_4 "Share (number of trans):restaurant/hotel/cafe"

		gen sectoral_trans_5 = sectoral_t_5/trans_perp
		label val sectoral_trans_5 sec_trans_5
		label var sectoral_trans_5 "Share (number of trans):internet-/mail-orders"

		gen sectoral_trans_6 = sectoral_t_6/trans_perp
		label val sectoral_trans_6 sec_trans_6
		label var sectoral_trans_6 "Share (number of trans):out-of-house-services"

		gen sectoral_trans_7 = sectoral_t_7/trans_perp
		label val sectoral_trans_7 sec_trans_7
		label var sectoral_trans_7 "Share (number of trans):in-house-services/expenditures to privat persons/pocketmoney"

		gen sectoral_trans_8 = sectoral_t_8/trans_perp
		label val sectoral_trans_8 sec_trans_8
		label var sectoral_trans_8 "Share (number of trans):drugstores, leisure, vending machines"

		gen sectoral_trans_9 = sectoral_t_9/trans_perp
		label val sectoral_trans_9 sec_trans_9
		label var sectoral_trans_9 "Share (number of trans):unknown or other"

	* P_ANONYM_CASH
		
		gen P_ANONYM_CASH=0 if f13_8==1  | f13_8==2 | f13_8==3
		replace P_ANONYM_CASH=1 if f14_8_1==1 & f14_8_2!=1 & f14_8_3!=1 & f14_8_4!=1 & f14_8_5!=1 & f14_8_6!=1 & f13_8==1
		label var P_ANONYM_CASH "Anonymity very important and only cash"
	
	* P_HABIT_CASH 
	
		gen P_HABIT_CASH=0 if f13_9==1  | f13_9==2 | f13_9==3
		replace P_HABIT_CASH=1 if f14_9_1==1 & f14_9_2!=1 & f14_9_3!=1 & f14_9_4!=1 & f14_9_5!=1 & f14_9_6!=1 & f13_9==1
		label var P_HABIT_CASH "HABIT very important and only cash"
	
	
	* schwelle_kpl~2a
	
		gen schwelle_kplus2a=.
		replace schwelle_kplus2a=0 if THRESH_CARD==0
		replace schwelle_kplus2a=5.01 if THRESH_CARD==5
		replace schwelle_kplus2a=20.01 if THRESH_CARD==20
		replace schwelle_kplus2a=50.01 if THRESH_CARD==50
		replace schwelle_kplus2a=100.01 if THRESH_CARD==100
		replace schwelle_kplus2a=500.01 if THRESH_CARD==500
		
	* schwelle_kpl~2b 
	
		gen schwelle_kplus2b=.
		replace schwelle_kplus2b=5 if THRESH_CARD==0
		replace schwelle_kplus2b=20 if THRESH_CARD==5
		replace schwelle_kplus2b=50 if THRESH_CARD==20
		replace schwelle_kplus2b=100 if THRESH_CARD==50
		replace schwelle_kplus2b=500 if THRESH_CARD==100
		replace schwelle_kplus2b=. if THRESH_CARD==0
		
	
*** CUTTER 1

	order id age age2 male education edu_m_high_uni EDU_LOW EDU_MEDIUM EDU_HIGH EDU_UNI pinc_mitte HH_INC employed unemployed other retired bik_07 bik_? risk_theft ec_card NUM_DIFF_PI P_EXPCONTR_CASH IA2_EXPC_LENGTH ausgaben ausgaben_length2 sec_pro_quest CASHP_ALL CASHP_MAINLOC CASHP_B100 SHARE_CASH_TRANS SHARE_CASH_VALUE THRESH_CARD NUM_DIFF_PI DIST_WITHDR fees ATM_USER AVGWITHDAM lnAVGWITHDAM thresh_nextwithdr lnamount withdraw_frq_unscaled anteil_barvol_gesamt  AVG_VAL_TRANS  sectoral_trans_* P_ANONYM_CASH P_HABIT_CASH schwelle_kplus2a schwelle_kplus2b 
	
	* add CASH_INCOME IA2_EXPC_INCOME IA2_EXPC_EDU IA2_EXPC_OLD for robustness checks
	
	keep age- schwelle_kplus2b
	
*** CUTTER 2	
	
	keep if ec_card==1
	drop ec_card
	
*** Check

		sum *
	
********** SAVE 

save "R:\Zentrale\6\Daten\6_Datenaustausch\Haushaltssurvey\Germany - Bargeldumfrage H\Analysen, Projekte, Stix\Paper II\Submissions\JMCB\Files for Publication\data\MSS_12_188_Using_Cash_to_Monitor_Liquidity_DATA.dta", replace





